<?php namespace EscapeWork\Manager\Banners\Commands;

use EscapeWork\Manager\Banners\Seeds\BannerTableSeeder;
use EscapeWork\Manager\Banners\Seeds\BannerGroupTableSeeder;
use Illuminate\Console\Command;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;

class ConfigureCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager-banners:configure';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Migrations, Seeds, plugins e tudo que precisar ser configurado.';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return void
     */
    public function fire()
    {
        $this->comment('--- Configurando escapework/manager-banners ---');

        # migrations
        $this->comment('Realizando as migrações do escapework/manager-banners...');
        $this->call('migrate', array('--package' => 'escapework/manager-banners'));

        # seed
        $this->comment('Fazendo os seeds...');

        $seeder = new BannerTableSeeder();
        $seeder->setContainer($this->laravel)->setCommand($this)->run();

        $seeder = new BannerGroupTableSeeder();
        $seeder->setContainer($this->laravel)->setCommand($this)->run();

        $this->info('escapework/manager-banners seeded!');

        # asset:publish
        $this->comment('Publicando assets do escapework/manager-banners...');
        $this->call('asset:publish', array('package' => 'escapework/manager-banners'));

        $this->comment('--- escapework/manager-banners configurado ---');
    }

    /**
     * Get the console command arguments.
     *
     * @return array
     */
    protected function getArguments()
    {
        return array();
    }

    /**
     * Get the console command options.
     *
     * @return array
     */
    protected function getOptions()
    {
        return array();
    }

}
