<?php namespace EscapeWork\Manager\Banners\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Banners\Repositories\Banner\BannerRepository;
use EscapeWork\Manager\Banners\Repositories\BannerGroup\BannerGroupRepository;
use View;
use Input;
use Redirect;
use Response;
use Config;
use App;

class BannerController extends ManagerController
{

    public function __construct(BannerRepository $banner, BannerGroupRepository $bannerGroup)
    {
        $this->banner      = $banner;
        $this->bannerGroup = $bannerGroup;

        # filters
        $this->enableDefaultFilters('banners');
    }

    public function index()
    {
        $view              = View::make(Config::get('manager-banners::views.banners.index'));
        $view->banners     = $this->banner->filterAndFetch(Input::all());
        $view->bannerGroup = $this->bannerGroup;

        return $view;
    }

    public function create()
    {
        $this->banner->fill(Input::old());

        $view              = View::make(Config::get('manager-banners::views.banners.form'));
        $view->banner      = $this->banner;
        $view->bannerGroup = $this->bannerGroup;
        $view->edit        = false;

        return $view;
    }

    public function store()
    {
        $this->banner->fill(Input::all());

        if (! $this->banner->validate()) {
            return Redirect::route('manager.banners.create')
                    ->withInput()
                    ->with('errors', Banner::$messages);
        }

        if (! $this->banner->uploadBanner(Input::file('banner'))) {
            return Redirect::route('manager.banners.create')
                    ->withInput()
                    ->with('errors', Banner::$messages);
        }

        $this->banner->save();

        return Redirect::route('manager.banners.index')
                ->with('message', 'O banner <strong>'.$this->banner->title.'</strong> foi inserido com sucesso!');
    }

    public function edit($id)
    {
        $this->banner = $this->banner->findOrFail($id);
        $this->banner->fill(Input::old());

        $view              = View::make(Config::get('manager-banners::views.banners.form'));
        $view->banner      = $this->banner;
        $view->bannerGroup = $this->bannerGroup;
        $view->edit        = true;

        return $view;
    }

    public function update($id)
    {
        $this->banner = $this->banner->findOrFail($id);
        $this->banner->fill(Input::all());

        if (! $this->banner->validate()) {
            return Redirect::route('manager.banners.edit', $this->banner->id)
                    ->withInput()
                    ->with('errors', Banner::$messages);
        }

        $this->banner->uploadBanner(Input::file('banner'));
        $this->banner->save();

        return Redirect::route('manager.banners.index')
                ->with('message', 'O banner <strong>'.$this->banner->title.'</strong> foi editado com sucesso!');
    }

    public function destroy($id)
    {
        $this->banner = $this->banner->findOrFail($id);
        $this->banner->delete();

        return Redirect::route('manager.banners.index')
                ->with('message', 'O banner <strong>'.$this->banner->title.'</strong> foi excluído com sucesso!');
    }

    public function updateActive($id)
    {
        if (! $this->banner = $this->banner->find($id)) {
            return Response::json(array(
                'error' => 'Banner não encontrado'
            ));
        }

        $this->banner->active = Input::get('active');
        $this->banner->save();

        return Response::json(array(
            'message' => 'O banner foi atualizado com sucesso'
        ));
    }

    public function updateOrder($id)
    {
        if (! $this->banner = $this->banner->find($id)) {
            return Response::json(array(
                'error' => 'Banner não encontrado'
            ));
        }

        $this->banner->order = Input::get('order');
        $this->banner->save();

        return Response::json(array(
            'message' => 'O banner foi atualizado com sucesso'
        ));
    }

    /**
     * Returning the banner sizes
     */
    public function sizes($banner_group_id)
    {
        $sizes = Config::get('manager-banners::sizes');
        $sizes = isset($sizes[$banner_group_id]) ? $sizes[$banner_group_id] : $sizes['default'];

        return Response::json($sizes);
    }
}
