<?php namespace EscapeWork\Manager\Banners\Models;

use EscapeWork\Manager\Banners\Extensions\BannerCollection;
use EscapeWork\LaravelHelpers\Eloquent;

class Banner extends Eloquent
{

    /**
     * Tabela
     */
    protected $table = 'banners';

    /**
     * Fillable fields
     */
    public $fillable = array(
        'id',
        'banner_group_id',
        'title',
        'description',
        'link',
        'target',
        'order',
        'active',
        'expire_at',
        'created_at',
        'updated_at',
    );

    /**
     * Tipos de imagens aceitas
     */
    public $acceptedImages = array(
        'image/jpg', 'image/jpeg', 'image/pjpg', 'image/pjpeg',
        'image/png'
    );

    /**
     * Diretórios
     */
    public
        $dir = 'files/banners',
        $url = 'files/banners';

    /**
     * Setando o link
     */
    public function setLinkAttribute($value)
    {
        if (filter_var($value, FILTER_VALIDATE_URL)) {
            $this->attributes['link'] = $value;
        } else {
            $value = 'http://' .$value;

            if (filter_var($value, FILTER_VALIDATE_URL)) {
                $this->attributes['link'] = $value;
            }
        }
    }

    /**
     * Setting the date attribute
     */
    public function setExpireAtAttribute($value)
    {
        $this->attributes['expire_at'] = to_timestamp($value, 'd/m/Y', 'Y-m-d');
    }

    /**
     * Setando o attributo de ativo
     */
    public function setActiveAttribute($value)
    {
        $this->attributes['active'] = $value == 1 ? 1 : 0;
    }

    /**
     * Setando a descrição
     */
    public function setDescriptionAttribute($value)
    {
        if ($value != '') {
            $this->attributes['description'] = $value;
        }
    }

    /**
     * Setando o target
     */
    public function setTargetAttribute($value)
    {
        $this->attributes['target'] = $value == '_blank' ? '_blank' : '_self';
    }

    /**
     * Active Scope
     */
    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }

    /**
     * Not Expired scope
     */
    public function scopeNotExpired($query)
    {
        return $query->where(function($query)
        {
            $query->whereNull('expire_at')
                  ->orWhere('expire_at', '>=', date('Y-m-d'));
        });
    }

    /**
     * Group relashionship
     */
    public function group()
    {
        return $this->belongsTo('EscapeWork\Manager\Banners\Models\BannerGroup', 'banner_group_id');
    }

    /**
     * Returning the active banners
     */
    public function getActives()
    {
        return $this->active()
                    ->notExpired()
                    ->orderBy('order', 'asc')
                    ->get();
    }

    /**
     * Nova coleção
     */
    public function newCollection(array $models = array())
    {
        return new BannerCollection($models);
    }

    /**
     * Retornando a URL da imagem
     */
    public function getUrl()
    {
        return $this->url;
    }

    /**
     * Retornando a URL da imagem
     */
    public function getDir()
    {
        return public_path() . '/' . $this->dir;
    }
}
